@@ -549,6 +549,14 @@ class FlexValueRun:
             .reset_index(drop=True)
         )
 
+    def get_all_trc_gas_benefits_df(self, user_inputs):
+        return pd.concat(
+            [
+                flx_project.calculate_trc_gas_benefits()
+                for flx_project in self.get_flexvalue_projects(user_inputs).values()
+            ]
+        )
+
     def get_total_trc_gas_benefits(self, user_inputs):
         """The total gas benefits across all FlexValueProjects
 
@@ -567,7 +575,7 @@ class FlexValueRun:
             [
                 flx_project.calculate_trc_gas_benefits()["total"].sum()
                 for flx_project in self.get_flexvalue_projects(user_inputs).values()
-            ],
+            ]
         )
 
     def get_all_output_tables(self, user_inputs):
@@ -652,7 +660,7 @@ class FlexValueRun:
                     }
                 )
                 for flx_project in self.get_flexvalue_projects(user_inputs).values()
-            ],
+            ]
         ).reset_index()
 
     def get_results(self, user_inputs):
@@ -682,9 +690,44 @@ class FlexValueRun:
         )
         elec_benefits = self.get_all_trc_electricity_benefits_df(user_inputs)
         gas_benefits = self.get_total_trc_gas_benefits(user_inputs)
-
         # if index wasn't already set with the ID colum, set it for joining to the output
         if user_inputs.index.name != "ID":
             user_inputs = user_inputs.set_index("ID")
         outputs_table = user_inputs.join(outputs_table).reset_index()
         return outputs_table, outputs_table_totals, elec_benefits, gas_benefits
+
+    def get_time_series_results(self, user_inputs):
+        """ Return raw time series electricity and gas benefits data as an iterator.
+
+        Parameters
+        ----------
+        user_inputs: pd.DataFrame
+            A dataframe containing all of the inputs for each measure/project/portoflio
+            in the FlexValueRun
+
+        Returns
+        -------       
+        An iterator in which each item is a tuple with the following elements:
+        
+        elec_benefits: pd.DataFrame
+            Returns an hourly time series load shape for each
+            measure/project/portoflio, concatanated into a single dataframe
+        gas_benefits: float
+            Returns a quarterly time series load shape for each
+            measure/project/portoflio, concatanated into a single dataframe
+        """
+        
+        
+        # In order to match the output of the get_results method, we need to 
+        # append all of the load shape column names to the data frame.  
+        load_shape_cols = [i.load_shape_df.columns[0] for i in self.get_flexvalue_projects(user_inputs).values()]
+
+        # Step through all projects in user_inputs and yield the elec and gas benefits 
+        for i in range(len(user_inputs)):            
+            row = user_inputs.iloc[i:i+1]
+            elec_benefits = self.get_all_trc_electricity_benefits_df(row)
+            for col in load_shape_cols:
+                if col not in elec_benefits.columns:
+                    elec_benefits.loc[:,col] = None
+            gas_benefits = self.get_all_trc_gas_benefits_df(row)
+            yield elec_benefits, gas_benefits
