@@ -249,3 +249,65 @@ def valid_utility_climate_zone_combos(utility, version):
 def valid_deer_load_shapes(version):
     """Returns all valid DEER load shapes"""
     click.echo("\n".join(get_all_valid_deer_load_shapes(version)))
+
+@cli.command()
+@click.option(
+    "--user-inputs-filepath",
+    required=True,
+    help="Filepath to the user-inputs CSV file that is used to calculate results",
+)
+@click.option(
+    "--metered-load-shape-filepath",
+    help="Optional filepath to the CSV file containing metered load shapes",
+)
+@click.option(
+    "--outputs-electricity-filepath",
+    default="outputs_time_series_electricity.csv",
+    show_default=True,
+    help="Filepath to where the time series electricity data will be saved",
+)
+@click.option(
+    "--outputs-gas-filepath",
+    default="outputs_time_series_gas.csv",
+    show_default=True,
+    help="Filepath to where the time series gas data will be saved",
+)
+@click.option(
+    "-v",
+    "--version",
+    default="2020",
+    show_default=True,
+    help="What version of the avoided costs data to use in the analysis",
+)
+def get_time_series_results(
+    user_inputs_filepath,
+    metered_load_shape_filepath,
+    outputs_electricity_filepath,
+    outputs_gas_filepath,
+    version,
+):
+    """ Return raw time series electricity and gas benefits data. """
+    metered_load_shape = (
+        pd.read_csv(metered_load_shape_filepath, index_col="hour_of_year")
+        if metered_load_shape_filepath
+        else None
+    )
+    user_inputs = pd.read_csv(user_inputs_filepath)
+    flexvalue_run = FlexValueRun(
+        metered_load_shape=metered_load_shape, database_version=version
+    )
+
+    outputs = flexvalue_run.get_time_series_results(
+        user_inputs
+    )
+    if os.path.exists(outputs_electricity_filepath):
+        os.remove(outputs_electricity_filepath)
+    if os.path.exists(outputs_gas_filepath):
+        os.remove(outputs_gas_filepath)
+    
+    for row in outputs:
+        
+        (outputs_electricity, outputs_gas) = row 
+        outputs_electricity.to_csv(outputs_electricity_filepath, mode='a', header= not os.path.exists(outputs_electricity_filepath), index=False)
+        outputs_gas.to_csv(outputs_gas_filepath, mode='a', header= not os.path.exists(outputs_gas_filepath), index=False)
+
